@@ -99,7 +99,7 @@ def create_app():
     swagger = Swagger(app, template=template)
     app.wsgi_app = ReverseProxied(app.wsgi_app)
     app.json_encoder = CustomJSONEncoder
-    cache.init_app(app, config={'CACHE_TYPE': 'simple'})
+    cache.init_app(app, config={'CACHE_TYPE': 'SimpleCache'})
 
 
 #    CORS(app)
@@ -121,12 +121,6 @@ def after_request(response):
                          'GET,PUT,POST,DELETE,OPTIONS')
     return response
 
-
-def make_key():
-    """Make a key that includes GET parameters."""
-    return request.full_path
-
-
 class AsyncWorker(threading.Thread):
     def __init__(self, worker_id):
         self.worker_id = worker_id
@@ -135,7 +129,6 @@ class AsyncWorker(threading.Thread):
     def run(self):
         while True:
             self.run_one()
-
             time.sleep(5)
 
     def run_one(self):
@@ -154,7 +147,11 @@ class AsyncWorkflow:
         try:
             self._run()
         except Exception as e:
-            print("failed", e)
+            logger.error("run failed unexplicably: %s", repr(e))
+            app.async_workflows[self.key] = dict(
+                output={}, 
+                exceptions=[serialize_workflow_exception(e)]
+            )
 
     def note(self, *args, **kwargs):
         if not hasattr(self, 'notes'):
@@ -220,7 +217,7 @@ class AsyncWorkflow:
                 nretry -= 1
                 time.sleep(1)
 
-        logger.error("output: %s", output)
+        logger.debug("output: %s", output)
 
         logger.info("updating key %s", self.key)
         app.async_workflows[self.key] = dict(output=output, exceptions=list(
@@ -236,7 +233,7 @@ class AsyncWorkflow:
         result = app.async_workflows[self.key]
 
         callback_payload = dict(
-            status='done'
+            action='done'
         )
         
         if re.match('^file://', self.callback):
@@ -280,7 +277,7 @@ def workflow(target, background=False, async_request=False):
     # async
     if async_request:
         key = hashlib.sha224(json.dumps(
-            dict(target=target, params=interpreted_parameters, callback=async_request_callback)).encode('utf-8')).hexdigest()
+            dict(target=target, params=interpreted_parameters)).encode('utf-8')).hexdigest()
 
         value = app.async_workflows.get(key, None)
 
@@ -433,7 +430,7 @@ def setup_routes(app):
         try:
             app.route('/api/v1.0/get/'+target, methods=['GET'], endpoint=endpoint)(
                 swag_from(target_specs)(
-                    cache.cached(timeout=cache_timeout, key_prefix=make_key, response_filter=response_filter, query_string=True)(
+                    cache.cached(timeout=cache_timeout, response_filter=response_filter, query_string=True)(
                         funcg(target)
                     )))
         except AssertionError as e:
